summaryrefslogtreecommitdiffstats
path: root/scripts/automation/regression/stateless_tests/stl_performance_test.py
diff options
context:
space:
mode:
authorimarom <imarom@cisco.com>2016-10-26 15:00:50 +0200
committerimarom <imarom@cisco.com>2016-10-26 15:22:47 +0200
commit7d129c00303a5df1d6af331781139dc2d447d0d8 (patch)
treeb606ea8a8bde53a69a27d128f55b349a55e20a9b /scripts/automation/regression/stateless_tests/stl_performance_test.py
parent270cf64af087f110fd69064017edc311ddf82025 (diff)
fixed performance issue (moved STRECH case to low priority cases)
Signed-off-by: imarom <imarom@cisco.com>
Diffstat (limited to 'scripts/automation/regression/stateless_tests/stl_performance_test.py')
-rw-r--r--scripts/automation/regression/stateless_tests/stl_performance_test.py14
1 files changed, 9 insertions, 5 deletions
diff --git a/scripts/automation/regression/stateless_tests/stl_performance_test.py b/scripts/automation/regression/stateless_tests/stl_performance_test.py
index a77c5c27..27c61cc0 100644
--- a/scripts/automation/regression/stateless_tests/stl_performance_test.py
+++ b/scripts/automation/regression/stateless_tests/stl_performance_test.py
@@ -180,7 +180,7 @@ class STLPerformance_Test(CStlGeneral_Test):
setup_cfg = self.get_benchmark_param('cfg')
scenario_cfg = {}
- scenario_cfg['name'] = "VM - 64 bytes, two CPUs"
+ scenario_cfg['name'] = "VM - 64 bytes, multi CPUs"
scenario_cfg['streams'] = self.build_perf_profile_vm(64)
scenario_cfg['core_count'] = setup_cfg['core_count']
@@ -191,12 +191,12 @@ class STLPerformance_Test(CStlGeneral_Test):
# two CPUs, VM, cached, 64 bytes
def test_performance_vm_multi_cpus_cached (self):
setup_cfg = self.get_benchmark_param('cfg')
scenario_cfg = {}
- scenario_cfg['name'] = "VM - 64 bytes, single CPU, cache size 1024"
+ scenario_cfg['name'] = "VM - 64 bytes, multi CPU, cache size 1024"
scenario_cfg['streams'] = self.build_perf_profile_vm(64, cache_size = 1024)
@@ -207,12 +207,12 @@ class STLPerformance_Test(CStlGeneral_Test):
self.execute_single_scenario(scenario_cfg)
# two CPUs, syn attack, 64 bytes
def test_performance_syn_attack_multi_cpus (self):
setup_cfg = self.get_benchmark_param('cfg')
scenario_cfg = {}
- scenario_cfg['name'] = "syn attack - 64 bytes, two CPUs"
+ scenario_cfg['name'] = "syn attack - 64 bytes, multi CPUs"
scenario_cfg['streams'] = self.build_perf_profile_syn_attack(64)
scenario_cfg['core_count'] = setup_cfg['core_count']
@@ -254,6 +254,10 @@ class STLPerformance_Test(CStlGeneral_Test):
self.c.add_streams(ports = [0], streams = scenario_cfg['streams'])
# use one core
+ cores_per_port = self.c.system_info.get('dp_core_count_per_port', 0)
+ if cores_per_port < scenario_cfg['core_count']:
+ assert 0, "test configuration requires {0} cores but only {1} per port are available".format(scenario_cfg['core_count'], cores_per_port)
+
core_mask = (2 ** scenario_cfg['core_count']) - 1
self.c.start(ports = [0], mult = scenario_cfg['mult'], core_mask = [core_mask])
@@ -191,12 +191,12 @@ class STLPerformance_Test(CStlGeneral_Test):
scenario_cfg['core_count'] = setup_cfg['core_count']
- # two CPUs, VM, cached, 64 bytes
+ # multi CPUs, VM, cached, 64 bytes
def test_performance_vm_multi_cpus_cached (self):
setup_cfg = self.get_benchmark_param('cfg')
@@ -207,12 +207,12 @@ class STLPerformance_Test(CStlGeneral_Test):
self.execute_single_scenario(scenario_cfg)
- # two CPUs, syn attack, 64 bytes
+ # multi CPUs, syn attack, 64 bytes
def test_performance_syn_attack_multi_cpus (self):
setup_cfg = self.get_benchmark_param('cfg')